==> enterprisemodules-wls_config-3.4.0.tar.gz: enterprisemodules-wls_config-3.4.0/lib/puppet/type/wls_dynamic_cluster.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_dynamic_cluster) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a dynamic cluster in an WebLogic domain.

    Here is an example on how you should use this:

        wls_dynamic_cluster{'DynamicCluster':
          ensure                 => 'present',
          calculated_listen_port => '0',  # '0' or '1'
          maximum_server_count   => '2',
          nodemanager_match      => 'Node1,Node2',
          server_name_prefix     => 'DynCluster-',
          server_template_name   => 'ServerTemplateWeb',
        }

    In this example you are managing a dynamic cluster in the default domain. When you want to
    manage a dynamic cluster in a specific domain, you can use:

        wls_dynamic_cluster{'my_domain/DynamicCluster':
          ensure                 => 'present',
          calculated_listen_port => '0',  # '0' or '1'
          maximum_server_count   => '2',
          nodemanager_match      => 'Node1,Node2',
          server_name_prefix     => 'DynCluster-',
          server_template_name   => 'ServerTemplateWeb',
        }

    Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/clustering.htm#INTRO336) for more information
    about configuring and managing datasources.

    EOD

    #
    # Only use elements on the path where this condition is true. The condition is
    # that is has specified serverTemplates
    #
    index_condition do |  name, path, wls_config |
      !wls_config.children("#{path}/#{name}/ServerTemplate/").empty?
    end

    on_create do
      Puppet.info "create #{name} "
      wls_config.create('Cluster', '/Clusters' , self[key_name])
      nil
    end

    bean_path('/Clusters/%{cluster_name}/DynamicServers')
    bean_type('DynamicServer')
    ensurable
    parameter :cluster_name
    parameter :domain
    parameter :name
    parameter :timeout
    property :server_name_prefix
    property :server_template_name
    property :nodemanager_match
    property :maximum_server_count
    property :calculated_listen_port
    extraproperties do
      property :calculated_listen_ports
      property :calculated_machine_names
      property :machine_name_match_expression
      property :maximum_dynamic_server_count
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :dynamic_cluster_cooloff_period_seconds
      property :dynamic_cluster_shutdown_timeout_seconds
      property :dynamic_cluster_size
      property :ignore_sessions_during_shutdown
      property :machine_match_expression
      property :machine_match_type
      property :max_dynamic_cluster_size
      property :min_dynamic_cluster_size
      property :server_template
      property :tags
      property :wait_for_all_sessions_during_shutdown
    end

    add_title_attributes(:cluster_name)
  end
end

==> enterprisemodules-wls_config-3.20.0.tar.gz: enterprisemodules-wls_config-3.20.0/lib/puppet/type/wls_dynamic_cluster.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_dynamic_cluster) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a dynamic cluster in an WebLogic domain.

    Here is an example on how you should use this:

        wls_dynamic_cluster{'DynamicCluster':
          ensure                 => 'present',
          calculated_listen_port => '0',  # '0' or '1'
          maximum_server_count   => '2',
          nodemanager_match      => 'Node1,Node2',
          server_name_prefix     => 'DynCluster-',
          server_template_name   => 'ServerTemplateWeb',
        }

    In this example you are managing a dynamic cluster in the default domain. When you want to
    manage a dynamic cluster in a specific domain, you can use:

        wls_dynamic_cluster{'my_domain/DynamicCluster':
          ensure                 => 'present',
          calculated_listen_port => '0',  # '0' or '1'
          maximum_server_count   => '2',
          nodemanager_match      => 'Node1,Node2',
          server_name_prefix     => 'DynCluster-',
          server_template_name   => 'ServerTemplateWeb',
        }

    Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/clustering.htm#INTRO336) for more information
    about configuring and managing datasources.

    DESC

    #
    # Only use elements on the path where this condition is true. The condition is
    # that is has specified serverTemplates
    #
    index_condition do |name, path, wls_config|
      !wls_config.children("#{path}/#{name}/ServerTemplate/").empty?
    end

    on_create do
      Puppet.info "create #{name} "
      wls_config.create('Cluster', '/Clusters', self[key_name])
      nil
    end

    bean_path('/Clusters/%<cluster_name>s/DynamicServers')
    bean_type('DynamicServer')
    ensurable
    parameter :cluster_name
    parameter :domain
    parameter :name
    parameter :timeout
    property :server_name_prefix
    property :server_template_name
    property :nodemanager_match
    property :maximum_server_count
    property :calculated_listen_port
    extraproperties do
      property :calculated_listen_ports
      property :calculated_machine_names
      property :machine_name_match_expression
      property :maximum_dynamic_server_count
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :dynamic_cluster_cooloff_period_seconds
      property :dynamic_cluster_shutdown_timeout_seconds
      property :dynamic_cluster_size
      property :ignore_sessions_during_shutdown
      property :machine_match_expression
      property :machine_match_type
      property :max_dynamic_cluster_size
      property :min_dynamic_cluster_size
      property :server_template
      property :tags
      property :wait_for_all_sessions_during_shutdown
    end

    add_title_attributes(:cluster_name)
  end
end
